==> billogram-foundation-3.13.10.tgz: package/modules/components/dropdown/DropdownState.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Dropdown from './Dropdown';
import DropdownState from './DropdownState';

import dropdownValueOptionState from './option-value/dropdownValueOptionState';


const TestDropdown = Dropdown({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdown'
});

const TestDropdownState = DropdownState({
    Component: TestDropdown
});

test('should change value when clicking option', () => {
    const onChange = jest.fn();
    const options = [
        dropdownValueOptionState({ text: 'A', value: 'a' }),
        dropdownValueOptionState({ text: 'B', value: 'b' }),
        dropdownValueOptionState({ text: 'C', value: 'c' })
    ];

    const dropdown = mount(
        <TestDropdownState
            onChange={ onChange }
            options={ options } />
    );

    dropdown.setState({ expanded: true });

    const elements = dropdown.find('TestDropdownValueOption');
    expect(elements.length).toBe(3);

    elements.at(1).simulate('click');

    expect(onChange).toHaveBeenCalledWith('b');
});

test('should expand when clicked and collapsed', () => {
    const dropdown = mount(
        <TestDropdownState />
    );

    dropdown.find(TestDropdown).simulate('click');

    expect(dropdown.state('expanded')).toBe(true);
});

test('should collapse when clicked and expanded', () => {
    const dropdown = mount(
        <TestDropdownState />
    );

    dropdown.setState({ expanded: true });
    dropdown.find(TestDropdown).simulate('click');

    expect(dropdown.state('expanded')).toBe(false);
});

==> billogram-foundation-4.7.7.tgz: package/modules/components/dropdown/DropdownState.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Dropdown from './Dropdown';
import DropdownState from './DropdownState';

import dropdownValueOptionState from './option-value/dropdownValueOptionState';


const TestDropdown = Dropdown({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdown',
});

const TestDropdownState = DropdownState({
    Component: TestDropdown,
});

test('should change value when clicking option', () => {
    const onChange = jest.fn();
    const options = [
        dropdownValueOptionState({ text: 'A', value: 'a' }),
        dropdownValueOptionState({ text: 'B', value: 'b' }),
        dropdownValueOptionState({ text: 'C', value: 'c' }),
    ];

    const dropdown = mount(
        <TestDropdownState
            onChange={ onChange }
            options={ options } />
    );

    dropdown.setState({ expanded: true });

    const elements = dropdown.find('TestDropdownValueOption');
    expect(elements.length).toBe(3);

    elements.at(1).simulate('click');

    expect(onChange).toHaveBeenCalledWith('b');
});

test('should expand when clicked and collapsed', () => {
    const dropdown = mount(
        <TestDropdownState />
    );

    dropdown.find(TestDropdown).simulate('click');

    expect(dropdown.state('expanded')).toBe(true);
});

test('should collapse when clicked and expanded', () => {
    const dropdown = mount(
        <TestDropdownState />
    );

    dropdown.setState({ expanded: true });
    dropdown.find(TestDropdown).simulate('click');

    expect(dropdown.state('expanded')).toBe(false);
});
